Function uacpi::utils::find_devices_at

source ·
pub fn find_devices_at<F: FnMut(&NamespaceNode) -> NsIterDecision>(
    parent: &NamespaceNode,
    hids: &[&CStr],
    cb: F,
) -> Result<(), Status>
Finds all the devices in the namespace starting at parent matching the specified hids. Only devices reported as present via _STA are checked. Any matching devices are then passed to the cb.