Function uacpi::utils::device_matches_pnp_id
source · pub fn device_matches_pnp_id(node: &NamespaceNode, list: &[&CStr]) -> boolExpand description
Checks whether the device at node matches any of the PNP ids provided in list.
This is done by first attempting to match the value returned from _HID
and then the value(s) from _CID.
Note that the presence of the device (_STA) is not verified here.